"""
    EMIL AccountingService

    The EMIL AccountingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.financial_transactions_api import FinancialTransactionsApi  # noqa: E501


class TestFinancialTransactionsApi(unittest.TestCase):
    """FinancialTransactionsApi unit test stubs"""

    def setUp(self):
        self.api = FinancialTransactionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_financial_transaction(self):
        """Test case for get_financial_transaction

        Retrieve the financial transaction  # noqa: E501
        """
        pass

    def test_list_financial_transactions(self):
        """Test case for list_financial_transactions

        List financial transactions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL AccountingService

    The EMIL AccountingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.personal_accounts_api import PersonalAccountsApi  # noqa: E501


class TestPersonalAccountsApi(unittest.TestCase):
    """PersonalAccountsApi unit test stubs"""

    def setUp(self):
        self.api = PersonalAccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_personal_account(self):
        """Test case for create_personal_account

        Create the Personal Account  # noqa: E501
        """
        pass

    def test_delete_personal_account(self):
        """Test case for delete_personal_account

        Delete the Personal Account  # noqa: E501
        """
        pass

    def test_get_personal_account(self):
        """Test case for get_personal_account

        Retrieve the Personal Account  # noqa: E501
        """
        pass

    def test_list_personal_accounts(self):
        """Test case for list_personal_accounts

        List Personal Accounts  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
